"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chalkPipe = require("chalk-pipe");
var ImageOperations_1 = require("../Enums/ImageOperations");
var InputType_1 = require("../Enums/InputType");
var OutputFormats_1 = require("../Enums/OutputFormats");
var FileUtils_1 = require("../Utils/FileUtils");
exports.default = {
    inputType: {
        type: "list",
        message: "What is your input type?",
        name: "inputType",
        choices: [{
                name: "File",
                value: InputType_1.default.File,
            }, {
                name: "Directory",
                value: InputType_1.default.Directory,
            }],
    },
    inputFilePath: {
        type: 'input',
        message: 'Input file path:',
        name: 'inputFilePath',
        validate: function (path) {
            if (!FileUtils_1.default.exists(path)) {
                return 'File not exists.';
            }
            else if (!FileUtils_1.default.isSupportedFile(path)) {
                return 'File is not supported.';
            }
            return true;
        },
    },
    outputFilePath: {
        type: 'input',
        message: 'Output file path:',
        name: 'outputFilePath',
    },
    inputDirPath: {
        type: 'input',
        message: 'Directory path:',
        name: 'inputDirPath',
        validate: function (path) {
            try {
                if (!FileUtils_1.default.isDirectory(path)) {
                    return 'Not directory.';
                }
                else {
                    var foundImages = FileUtils_1.default.dirFiles(path, FileUtils_1.default.INPUT_FORMATS);
                    if (foundImages.length === 0) {
                        return 'Not found image.';
                    }
                }
            }
            catch (err) {
                return 'Invalid path.';
            }
            return true;
        },
    },
    outputDirPath: {
        type: 'input',
        message: 'Output directory path:',
        name: 'outputDirPath',
        validate: function (path) {
            try {
                if (!FileUtils_1.default.isDirectory(path)) {
                    return 'Not directory.';
                }
            }
            catch (err) {
                return 'Invalid path.';
            }
            return true;
        },
    },
    suffix: {
        type: 'input',
        message: 'Enter the suffix:',
        name: 'suffix',
    },
    prefix: {
        type: 'input',
        message: 'Enter the prefix:',
        name: 'prefix',
    },
    suffixOrPrefix: {
        type: 'list',
        message: 'Do you want suffix or prefix?',
        name: 'suffixOrPrefix',
        choices: [{
                name: 'Prefix',
                value: 'prefix',
            }, {
                name: 'Suffix',
                value: 'suffix',
            }, {
                name: 'No',
                value: 'no',
            }],
    },
    operations: {
        type: 'list',
        message: 'What do you want?',
        name: 'operation',
        choices: [{
                name: 'Optimize',
                value: ImageOperations_1.default.Optimize,
            }, {
                name: 'Convert',
                value: ImageOperations_1.default.Convert,
            }, {
                name: 'Crop',
                value: ImageOperations_1.default.Crop,
            }, {
                name: 'Resize',
                value: ImageOperations_1.default.Resize,
            }, {
                name: 'Rotate',
                value: ImageOperations_1.default.Rotate,
            }],
    },
    autoOrient: {
        type: 'confirm',
        message: 'Auto orientate the images?',
        name: 'autoOrient',
    },
    isSetDirection: {
        type: 'confirm',
        message: 'Would you like to set direction?',
        name: 'isSetDirection',
    },
    direction: {
        type: 'list',
        message: 'Select the direction:',
        name: 'direction',
        choices: [
            { name: 'NorthWest', value: 'NorthWest' },
            { name: 'North', value: 'North' },
            { name: 'NorthEast', value: 'NorthEast' },
            { name: 'West', value: 'West' },
            { name: 'Center', value: 'Center' },
            { name: 'East', value: 'East' },
            { name: 'SouthWest', value: 'SouthWest' },
            { name: 'South', value: 'South' },
            { name: 'SouthEast', value: 'SouthEast' },
        ],
    },
    outputType: {
        type: 'list',
        message: 'The file format to be converted:',
        name: 'outputType',
        choices: Object.keys(OutputFormats_1.default)
            .map(function (key) { return ({
            name: key + " (." + OutputFormats_1.default[key] + ")",
            value: "" + OutputFormats_1.default[key],
        }); }),
    },
    quality: {
        type: 'input',
        message: 'Set the output quality (1-100):',
        name: 'quality',
        default: 100,
        validate: function (value) {
            var quality = parseInt(value, 10);
            if (Number.isInteger(quality)) {
                if (quality <= 0 || quality > 100) {
                    return 'Enter a value between 1 - 100.';
                }
            }
            else {
                return 'Type the number.';
            }
            return true;
        },
    },
    backgroundColor: {
        type: 'input',
        message: 'Background color:',
        name: 'backgroundColor',
        transformer: function (color) {
            return chalkPipe(color)(color);
        },
    },
    degrees: {
        type: 'input',
        message: 'Degrees:',
        name: 'degrees',
        validate: function (value) {
            var quality = parseInt(value, 10);
            if (Number.isInteger(quality)) {
                if (quality <= 0 || quality > 360) {
                    return 'Enter a value between 1 - 360.';
                }
            }
            else {
                return 'Type the number.';
            }
            return true;
        },
    },
    ignoreAspectRatio: {
        type: 'confirm',
        message: 'Ignore aspect ratio when resizing?',
        name: 'ignoreAspectRatio',
    },
    size: {
        type: 'input',
        message: 'Size e.g(48x48, x48, 48x):',
        name: 'size',
        validate: function (value) {
            value = value.toLowerCase();
            if (value.search('x') !== -1) {
                var _a = value.split('x').map(function (v) { return parseInt(v, 10); }), width = _a[0], height = _a[1];
                if (isNaN(width) && isNaN(height)) {
                    return 'You can only leave one value empty!';
                }
                else {
                    return true;
                }
            }
            else {
                return 'Enter in the correct format!';
            }
        },
    },
    width: {
        type: 'input',
        message: 'Width:',
        name: 'width',
    },
    height: {
        type: 'input',
        message: 'Height:',
        name: 'height',
    },
    x: {
        type: 'input',
        message: 'Left distance of crop:',
        name: 'x',
        validate: function (value) {
            var quality = parseInt(value, 10);
            if (Number.isInteger(quality)) {
                if (quality < 0) {
                    return 'Must be greater than 0.';
                }
            }
            else {
                return 'Type the number.';
            }
            return true;
        },
    },
    y: {
        type: 'input',
        message: 'Top distance of crop:',
        name: 'y',
        validate: function (value) {
            var quality = parseInt(value, 10);
            if (Number.isInteger(quality)) {
                if (quality < 0) {
                    return 'Must be greater than 0.';
                }
            }
            else {
                return 'Type the number.';
            }
            return true;
        },
    },
};
//# sourceMappingURL=index.js.map